@@ -208,13 +208,14 @@ from abc import abstractmethod, ABC
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
-from ae.inspector import stack_vars, try_eval                                                             # type: ignore
+from ae.base import stack_vars                                                                            # type: ignore
+from ae.dynamicod import try_eval                                                                         # type: ignore
 from ae.i18n import default_language, get_f_string, get_text, register_package_translations, translation  # type: ignore
 from ae.gui_app import (                                                                                  # type: ignore
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.3.45'
+__version__ = '0.3.46'
 
 
 register_package_translations()
